summaryrefslogtreecommitdiff
path: root/package/source
diff options
context:
space:
mode:
Diffstat (limited to 'package/source')
-rw-r--r--package/source/xstor/ohierarchyholder.cxx4
-rw-r--r--package/source/xstor/owriteablestream.cxx2
-rw-r--r--package/source/xstor/xstorage.cxx8
-rw-r--r--package/source/xstor/xstorage.hxx2
-rw-r--r--package/source/zippackage/ZipPackage.cxx2
-rw-r--r--package/source/zippackage/zipfileaccess.cxx2
6 files changed, 10 insertions, 10 deletions
diff --git a/package/source/xstor/ohierarchyholder.cxx b/package/source/xstor/ohierarchyholder.cxx
index 70163505865a..5a0e1306bc3f 100644
--- a/package/source/xstor/ohierarchyholder.cxx
+++ b/package/source/xstor/ohierarchyholder.cxx
@@ -120,8 +120,8 @@ uno::Reference< embed::XExtendedStorageStream > OHierarchyElement_Impl::GetStrea
uno::Reference< embed::XTransactedObject > xTransact( xResult, uno::UNO_QUERY );
if ( xTransact.is() )
{
- // the existance of the transacted object means that the stream is opened for writing also
- // so the whole chain must be commited
+ // the existence of the transacted object means that the stream is opened for writing also
+ // so the whole chain must be committed
uno::Reference< embed::XTransactionBroadcaster > xTrBroadcast( xTransact, uno::UNO_QUERY_THROW );
xTrBroadcast->addTransactionListener( static_cast< embed::XTransactionListener* >( this ) );
}
diff --git a/package/source/xstor/owriteablestream.cxx b/package/source/xstor/owriteablestream.cxx
index 0787d9c9e5bd..e968def72ff1 100644
--- a/package/source/xstor/owriteablestream.cxx
+++ b/package/source/xstor/owriteablestream.cxx
@@ -1031,7 +1031,7 @@ void OWriteStream_Impl::Revert()
}
else
{
- // the original stream was aready parsed
+ // the original stream was already parsed
if ( !m_bOrigRelInfoBroken )
m_nRelInfoStatus = RELINFO_READ;
else
diff --git a/package/source/xstor/xstorage.hxx b/package/source/xstor/xstorage.hxx
index a2a06172d27a..8f039e6fedb0 100644
--- a/package/source/xstor/xstorage.hxx
+++ b/package/source/xstor/xstorage.hxx
@@ -170,7 +170,7 @@ struct OStorage_Impl
SwitchablePersistenceStream* m_pSwitchStream;
- sal_Int32 m_nStorageType; // the mode in wich the storage is used
+ sal_Int32 m_nStorageType; // the mode in which the storage is used
// the _rels substorage that is handled in a special way in embed::StorageFormats::OFOPXML
SotElement_Impl* m_pRelStorElement;
diff --git a/package/source/zippackage/ZipPackage.cxx b/package/source/zippackage/ZipPackage.cxx
index e43475c9abd7..b945d54dd3b1 100644
--- a/package/source/zippackage/ZipPackage.cxx
+++ b/package/source/zippackage/ZipPackage.cxx
@@ -1390,7 +1390,7 @@ uno::Reference< XActiveDataStreamer > ZipPackage::openOriginalForOutput()
void SAL_CALL ZipPackage::commitChanges()
throw( WrappedTargetException, RuntimeException )
{
- // lock the component for the time of commiting
+ // lock the component for the time of committing
::osl::MutexGuard aGuard( m_aMutexHolder->GetMutex() );
if ( m_eMode == e_IMode_XInputStream )
diff --git a/package/source/zippackage/zipfileaccess.cxx b/package/source/zippackage/zipfileaccess.cxx
index 4b2fa0157937..6df00f182bc4 100644
--- a/package/source/zippackage/zipfileaccess.cxx
+++ b/package/source/zippackage/zipfileaccess.cxx
@@ -65,7 +65,7 @@ OZipFileAccess::~OZipFileAccess()
if ( !m_bDisposed )
{
try {
- m_refCount++; // dispose will use refcounting so the further distruction must be avoided
+ m_refCount++; // dispose will use refcounting so the further destruction must be avoided
dispose();
} catch( uno::Exception& )
{}
diff --git a/package/source/xstor/xstorage.cxx b/package/source/xstor/xstorage.cxx
index 93ceab27db8e..6fd43fbc70a4 100644
--- a/package/source/xstor/xstorage.cxx
+++ b/package/source/xstor/xstorage.cxx
@@ -71,7 +71,7 @@ struct StorInternalData_Impl
::cppu::OMultiTypeInterfaceContainerHelper m_aListenersContainer; // list of listeners
::cppu::OTypeCollection* m_pTypeCollection;
sal_Bool m_bIsRoot;
- sal_Int32 m_nStorageType; // the mode in wich the storage is used
+ sal_Int32 m_nStorageType; // the mode in which the storage is used
sal_Bool m_bReadOnlyWrap;
OChildDispListener_Impl* m_pSubElDispListener;
@@ -1062,7 +1062,7 @@ void OStorage_Impl::Commit()
// in case of a new empty storage it is possible that the contents are still not read
// ( the storage of course has no contents, but the initialization is postponed till the first use,
// thus if a new storage was created and commited immediatelly it must be initialized here )
ReadContents();
// if storage is commited it should have a valid Package representation
@@ -1180,7 +1180,7 @@ void OStorage_Impl::Commit()
{
// the element must be just copied to the new temporary package folder
// the connection with the original package should not be lost just because
- // the element is still refered by the folder in the original hierarchy
+ // the element is still referred by the folder in the original hierarchy
uno::Any aPackageElement = m_xPackageFolder->getByName( (*pElementIter)->m_aOriginalName );
xNewPackageFolder->insertByName( (*pElementIter)->m_aName, aPackageElement );
}
@@ -1545,7 +1545,7 @@ SotElement_Impl* OStorage_Impl::InsertElement( ::rtl::OUString aName, sal_Bool b
OSL_ENSURE( (*pElementIter)->m_bIsRemoved, "Try to insert an element instead of existing one!\n" );
if ( (*pElementIter)->m_bIsRemoved )
{
- OSL_ENSURE( !(*pElementIter)->m_bIsInserted, "Inserted elements must be deleted immediatelly!\n" );
+ OSL_ENSURE( !(*pElementIter)->m_bIsInserted, "Inserted elements must be deleted immediately!\n" );
pDeletedElm = *pElementIter;
break;
}
@@ -1062,7 +1062,7 @@ void OStorage_Impl::Commit()
// in case of a new empty storage it is possible that the contents are still not read
// ( the storage of course has no contents, but the initialization is postponed till the first use,
- // thus if a new storage was created and commited immediatelly it must be initialized here )
+ // thus if a new storage was created and commited immediately it must be initialized here )
ReadContents();
// if storage is commited it should have a valid Package representation